@@ -98,12 +98,12 @@ plot_mixture <- function(x, y, type = 'score', npts = 200, degrees = 45,
     pis <- extract.mirt(x, 'pis')
     if(!(type %in% c('info', 'SE', 'infoSE', 'trace', 'score', 'itemscore',
                      'infocontour', 'infotrace', 'scorecontour')))
-        stop('type supplied is not supported')
+        stop('type supplied is not supported', call.=FALSE)
     if (any(degrees > 90 | degrees < 0))
         stop('Improper angle specified. Must be between 0 and 90.', call.=FALSE)
     rot <- list(x = rot[[1]], y = rot[[2]], z = rot[[3]])
     nfact <- x@Model$nfact
-    if(nfact > 3) stop("Can't plot high dimensional solutions.", call.=FALSE)
+    if(nfact > 3) stop("Can't plot high dimensional models.", call.=FALSE)
     J <- x@Data$nitems
     theta <- seq(theta_lim[1L],theta_lim[2L],length.out=npts/(nfact^2))
     ThetaFull <- Theta <- thetaComb(theta, nfact)
