@@ -79,6 +79,32 @@
 #' RMSD_DIF(MGmod)
 #' RMSD_DIF(MGmod, flag = .03)
 #'
+#' #################
+#' # NA placeholders included when groups do not respond to specific items
+#'
+#' a1 <- a2 <- rlnorm(20)
+#' d <- d2 <- rnorm(20)
+#' # item 5 contains DIF
+#' a2[5] <- a1[5] + 1
+#' d2[5] <- d[5] - 1/2
+#' g <- rbeta(20, 5, 17)
+#'
+#' dat1 <- simdata(a1, d, guess = g, N=1000, itemtype = '3PL')
+#' dat1[, 11:13] <- NA  # items 11:13 items NA for g1
+#' dat2 <- simdata(a2, d2, guess = g, N=1000, itemtype = '3PL',
+#'    mu=1/4, sigma=matrix(.75))
+#' dat2[,1:3] <- NA # items 1:3 items NA for g2
+#' dat <- rbind(dat1, dat2)
+#' group <- c(rep('g1', 1000), rep('g2', 1000))
+#'
+#' mod <- multipleGroup(dat, "Theta = 1-20
+#'                             PRIOR = (1-20, g, norm, -1, 0.5)",
+#'                      group=group, itemtype='3PL',
+#'                      invariance = c(colnames(dat), 'free_mean', 'free_var'))
+#' coef(mod, simplify = TRUE)
+#'
+#' RMSD_DIF(mod)
+#' RMSD_DIF(mod, flag = .03)
 #'
 #' #################
 #' # polytomous example
@@ -142,9 +168,12 @@ RMSD_DIF <- function(pooled_mod, flag = 0, probfun = TRUE, dentype = 'norm'){
         # make wider grid for better numerical integration
         Theta <- matrix(seq(-6,6,length.out = 201))
 
+        tmpdat <- subset(dat, group == which.group)
+        tmpdat <- tmpdat[,apply(tmpdat, 2, function(x) all(is.na(x)))]
         mod_g <- mirt(subset(dat, group == which.group), nfact,
                       itemtype = extract.mirt(smod, 'itemtype'),
-                      pars = sv, technical = list(storeEtable=TRUE, customTheta=Theta))
+                      pars = sv, technical = list(storeEtable=TRUE, customTheta=Theta,
+                                                  customK=extract.mirt(pooled_mod, 'K')))
         Etable <- mod_g@Internals$Etable[[1]]$r1
 
         # standard normal dist for theta
@@ -187,6 +216,7 @@ RMSD_DIF <- function(pooled_mod, flag = 0, probfun = TRUE, dentype = 'norm'){
             items[i, nms[[i]]] <- ret2[[i]]
         if(flag > 0)
             items[items < flag] <- NA
+        items[is.nan(items)] <- NA
         items <- as.data.frame(items)
         items <- as.mirt_df(items)
 
