@@ -1,8 +1,8 @@
 #' Extract Empirical Estimating Functions
 #'
 #' A function for extracting the empirical estimating functions of a fitted
-#' \code{\link{mirt}}, \code{\link{multipleGroup}} or \code{\link{bfactor}}
-#' model. This is the derivative of the log-likelihood with respect to the
+#' \code{\link{mirt}}, \code{\link{multipleGroup}}, \code{\link{bfactor}}, or
+#' \code{\link{mdirt}} model. This is the derivative of the log-likelihood with respect to the
 #' parameter vector, evaluated at the observed (case-wise) data. In other
 #' words, this function returns the case-wise scores, evaluated at the fitted
 #' model parameters. Currently, models fitted via the \code{EM} or \code{BL}
@@ -13,8 +13,8 @@
 #' @return An n x k matrix corresponding to n observations and k parameters
 #'
 #' @aliases estfun.AllModelClass
-#' @param x a fitted model object of class \code{SingleGroupClass} or
-#'   \code{MultipleGroupClass}
+#' @param x a fitted model object of class \code{SingleGroupClass},
+#'   \code{MultipleGroupClass}, or \code{DiscreteClass}
 #' @param weights by default, the \code{survey.weights} which were (optionally)
 #'   specified when fitting the model are included to calculate the scores.
 #'   If specified by the user, this should be a numeric vector of length equal
@@ -27,10 +27,12 @@
 #' scores (i.e., setting their expected values to 0). If the case-wise scores were
 #' obtained from maximum likelihood estimates, this setting does not affect the result.
 #'
-#' @author Lennart Schneider \email{lennart.sch@@web.de}; centering argument contributed by Rudolf Debelak (\email{rudolf.debelak@psychologie.uzh.ch})
+#' @author Lennart Schneider \email{lennart.sch@@web.de} and Phil Chalmers;
+#' centering argument contributed by Rudolf Debelak
+#' (\email{rudolf.debelak@psychologie.uzh.ch})
 #' @keywords scores
 #' @seealso \code{\link{mirt}}, \code{\link{multipleGroup}},
-#'   \code{\link{bfactor}}
+#'   \code{\link{bfactor}}, \code{\link{mdirt}}
 #' @export
 #'
 #' @examples
@@ -45,6 +47,15 @@
 #' vc1 <- vcov(mod1)
 #' all.equal(crossprod(sc1), chol2inv(chol(vc1)), check.attributes = FALSE)
 #'
+#' # Discrete group
+#' modd <- mdirt(expand.table(LSAT7), 2, SE = TRUE, SE.type = "crossprod")
+#' sc1 <- estfun.AllModelClass(modd)
+#' # get the gradient
+#' colSums(sc1)
+#' # calculate the OPG estimate of the variance-covariance matrix "by hand"
+#' vc1 <- vcov(modd)
+#' all.equal(crossprod(sc1), chol2inv(chol(vc1)), check.attributes = FALSE)
+#'
 #' # fit a multiple group 2PL and do the same as above
 #' group <- rep(c("G1", "G2"), 500)
 #' mod2 <- multipleGroup(expand.table(LSAT7), 1, group, SE = TRUE,
@@ -83,19 +94,30 @@
 estfun.AllModelClass <- function(x, weights = extract.mirt(x, "survey.weights"), centering=FALSE)
 {
   ## check class
+    epars <- mod2values(x)
+    was_discrete <- FALSE
+  if(inherits(x, 'DiscreteClass')){
+      was_discrete <- TRUE
+      class(x) <- "SingleGroupClass"
+  }
   stopifnot(class(x) %in% c("SingleGroupClass", "MultipleGroupClass"))
   ## check estimation method
   stopifnot(x@Options$method %in% c("EM", "BL"))
+
   ## check latent regression
   if(length(x@Model$lrPars)) {
-    stop("Scores computations currently not supported for latent regression estimates.")
+    stop("Scores computations currently not supported for latent regression estimates.", call.=FALSE)
   }
   ## check items
   CUSTOM.IND <- x@Internals$CUSTOM.IND
   SLOW.IND <- x@Internals$SLOW.IND
+  if(was_discrete){
+      jj <- extract.mirt(x, 'nitems') + 1L
+      SLOW.IND <- SLOW.IND[SLOW.IND != jj]
+  }
   whichitems <- unique(c(CUSTOM.IND, SLOW.IND))
   if(length(whichitems)) {
-    stop("Scores computations currently not supported for at least one of the supplied items.")
+    stop("Scores computations currently not supported for at least one of the supplied items.", call.=FALSE)
   }
   ## get relevant model info
   constrain <- x@Model$constrain
@@ -119,7 +141,7 @@ estfun.AllModelClass <- function(x, weights = extract.mirt(x, "survey.weights"),
     prior <- Priorbetween <- list(matrix(0))
   }
   pars <-
-  if(ngroups == 1L) {
+  if(ngroups == 1L && !was_discrete) {
       list(x@ParObjects$pars)
   } else {
       lapply(x@ParObjects$pars, function(pr) pr@ParObjects$pars)
@@ -127,13 +149,12 @@ estfun.AllModelClass <- function(x, weights = extract.mirt(x, "survey.weights"),
   Ls <- makeLmats(pars, constrain)
   L <- Ls$L
   redun_constr <- Ls$redun_constr
-  epars <- mod2values(x)
   epars$group <- factor(epars$group, levels = groupNames)
   eparsgroup <- split(epars, epars$group)
   sel <- lapply(eparsgroup, function(grp) grp$parnum[grp$est])
   ## constrains: cb = between groups, cw = within groups
   if(length(constrain)) {
-    if(ngroups > 1L) {
+    if(ngroups > 1L || was_discrete) {
       constraingroup <- lapply(constrain, function(cst) epars$group[cst])
       cb <- which(sapply(constraingroup, function(cst) !any(duplicated(cst))))
       if(length(cb) == 0L) {
