@@ -9,7 +9,7 @@ setMethod(
 	                      returnER = FALSE, verbose = TRUE, gmean, gcov,
 	                      plausible.draws, full.scores.SE, return.acov = FALSE,
                           QMC, custom_den = NULL, custom_theta = NULL,
-	                      min_expected, plausible.type, start,
+	                      min_expected, plausible.type, start, EAPsum.scores,
 	                      use_dentype_estimate, leave_missing = FALSE, ...)
 	{
         den_fun <- mirt_dmvnorm
@@ -69,7 +69,7 @@ setMethod(
                     mu=fs, sig=fs_acov))
                 if(any(sapply(jit, is.nan)))
                     stop('Could not draw unique plausible values. Response pattern ACOVs may
-                         not be positive definite')
+                         not be positive definite', call.=FALSE)
                 ret <- vector('list', plausible.draws)
                 completely_missing <- extract.mirt(object, 'completely_missing')
                 for(i in seq_len(plausible.draws)){
@@ -146,6 +146,9 @@ setMethod(
                 newmod@Data <- list(data=rp, tabdata=large$tabdata2, K=object@Data$K[pick],
                                     tabdatalong=large$tabdata, Freq=large$Freq, ngroups=1L,
                                     covdata=covdata, mins=rep(0L, ncol(response.pattern))[pick])
+                if(length(object@Internals$CUSTOM.IND))
+                    newmod@Internals$CUSTOM.IND <- c(1:length(pick))[
+                        pick %in% object@Internals$CUSTOM.IND]
                 if(!is.null(covdata)){
                     newmod@Data$fulldata <- list(large$tabdata)
                     lrPars <- newmod@ParObjects$lrPars
@@ -215,6 +218,7 @@ setMethod(
         if(!is.null(gcov)) gp$gcov <- gcov
         if(method == 'EAPsum') return(EAPsum(object, full.scores=full.scores, full.scores.SE=full.scores.SE,
                                              quadpts=quadpts, gp=gp, verbose=verbose,
+                                             EAPsum.scores=EAPsum.scores,
                                              item_weights=item_weights, return.acov=return.acov,
                                              CUSTOM.IND=CUSTOM.IND, theta_lim=theta_lim,
                                              discrete=discrete, QMC=QMC, den_fun=den_fun,
@@ -439,6 +443,7 @@ setMethod(
                 whc <- which(converge_info_mat != 1)
                 warning(paste0("The following factor score estimates failed to converge successfully:\n    ",
                                paste0(whc, collapse=',')), call.=FALSE)
+                attr(scoremat, 'failed2converge') <- whc
             }
             return(scoremat)
 		} else {
@@ -714,7 +719,7 @@ EAPsum <- function(x, full.scores = FALSE, full.scores.SE = FALSE,
                    which.items = 2:length(x@ParObjects$pars)-1,
                    use_dentype_estimate = FALSE, pis, leave_missing,
                    item_weights = rep(1, extract.mirt(x, 'nitems')),
-                   return.acov, nfact, ...){
+                   EAPsum.scores, return.acov, nfact, ...){
     calcL1 <- function(itemtrace, K, itemloc){
         J <- length(K)
         L0 <- L1 <- matrix(1, sum(K-1L) + 1L, ncol(itemtrace))
@@ -859,7 +864,7 @@ EAPsum <- function(x, full.scores = FALSE, full.scores.SE = FALSE,
     factorNames <- extract.mirt(x, 'factorNames')
     colnames(thetas) <- factorNames[!grepl('\\(',factorNames)]
     colnames(SEthetas) <- paste0('SE_', colnames(thetas))
-    ret <- data.frame(Sum.Scores=Sum.Scores + sum(x@Data$min), thetas, SEthetas)
+    ret <- data.frame(Sum.Scores=Sum.Scores + sum(x@Data$mins), thetas, SEthetas)
     rownames(ret) <- ret$Sum.Scores
     if(full.scores){
         dat <- x@Data$data
@@ -885,7 +890,7 @@ EAPsum <- function(x, full.scores = FALSE, full.scores.SE = FALSE,
             stop('EAPsum scores are not meaningful when data contains missing values. If possible, pass na.rm=TRUE',
                  call.=FALSE)
         E <- L1 %*% prior * nrow(dat)
-        adj <- extract.mirt(x, 'mins')
+        adj <- mins <- extract.mirt(x, 'mins')
         dat <- t(t(dat) - adj)
         Otmp <- matrix(table(sort(rowSums(dat))))
         got <- as.numeric(names(table(sort(rowSums(dat))))) + 1L
@@ -898,13 +903,36 @@ EAPsum <- function(x, full.scores = FALSE, full.scores.SE = FALSE,
         X2 <- tmp$X2
         tmp <- suppressWarnings(expand.table(cbind(ret[,2L:(ncol(ret)-1L)], ret$observed)))
         pick <- seq_len(x@Model$nfact)
+        EX <- sum(Sum.Scores * rowSums(t(t(L1) * prior))) + sum(mins)
+        VARX <- sum(( (Sum.Scores + sum(mins)) - EX)^2 *
+                        rowSums(t(t(L1) * prior)))
+        itemx <- matrix(0, nrow=J, ncol=2)
+        colnames(itemx) <- c('E.x', 'VAR.x')
+        rownames(itemx) <- extract.mirt(x, "itemnames")
+        for(i in 1L:J){
+            si <- 0L:(K[i]-1L)
+            px <- colSums(t(itemtrace[itemloc[i]:(itemloc[i+1L]-1L),]) * prior)
+            ex <- sum(si * px)
+            varx <- sum((si - ex)^2 * px)
+            itemx[i,1L] <- ex + mins[i]
+            itemx[i,2L] <- varx
+        }
         rxx <- apply(tmp[,pick, drop=FALSE], 2L, var) /
             (apply(tmp[,pick, drop=FALSE], 2L, var) + apply(tmp[,pick+x@Model$nfact, drop=FALSE], 2L,
                                                             function(x) mean(x^2)))
         names(rxx) <- paste0('rxx_', factorNames)
         fit <- data.frame(df=df, X2=X2, p.X2 = suppressWarnings(pchisq(X2, df, lower.tail=FALSE)))
+        rxx.alpha <- (J / (J-1)) * (1 - sum(itemx[,2])/VARX)
+        fit$SEM.alpha <- sqrt(VARX) * sqrt(1 - rxx.alpha)
+        fit$rxx.alpha <- rxx.alpha
         fit <- cbind(fit, t(as.data.frame(rxx)))
         rownames(fit) <- 'stats'
+        fit <- as.mirt_df(fit)
+        if(EAPsum.scores){
+            fit <- list(fit=fit,
+                        Sum.Scores=as.mirt_df(data.frame(E.X=EX, VAR.X=VARX)),
+                        Item.Scores=as.mirt_matrix(itemx))
+        }
         attr(ret, 'fit') <- fit
         ret$std.res <- with(ret, sqrt( (observed - expected)^2 / expected))
         if(!all(item_weights == 1)){ # TODO can this be fixed?
@@ -949,7 +977,7 @@ MAP <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND, it
 ML <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND,
                item_weights, hessian, return.acov = FALSE, den_fun, max_theta, ...){
     if(any(scores[ID, ] %in% c(-Inf, Inf, NA)))
-        return(c(scores[ID, ], rep(NA, ncol(scores) + 1L)))
+        return(c(scores[ID, ], rep(NA, ncol(scores) + !return.acov)))
     estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars,patdata=tabdata[ID, ], den_fun=NULL,
                         itemloc=itemloc, gp=gp, prodlist=prodlist, ML=TRUE, max_theta=max_theta,
                         hessian=hessian, item_weights=item_weights,
@@ -964,14 +992,15 @@ ML <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND,
             vcov <- matrix(0, length(pick), length(pick))
             vcov[pick,pick] <- vcov_small
         } else vcov <- try(solve(estimate$hessian), TRUE)
-        if(return.acov) return(vcov)
         SEest <- try(sqrt(diag(vcov)), TRUE)
         if(is(vcov, 'try-error') || is(SEest, 'try-error') || any(is.nan(SEest))){
+            vcov <- matrix(NA, ncol(scores), ncol(scores))
             SEest <- rep(NA, ncol(scores))
         } else if(any(SEest > 30)){
             est[SEest > 30] <- Inf * sign(est[SEest > 30])
             SEest[SEest > 30] <- NA
         }
+        if(return.acov) return(as.vector(vcov))
     } else SEest <- rep(NA, ncol(scores))
     return(c(est, SEest, estimate$code))
 }
@@ -1053,4 +1082,4 @@ EAP_classify <- function(ID, log_itemtrace, tabdata, W, nclass){
     }
     probs <- matrix(expLW / nc, ncol=nclass)
     colSums(probs)
-}
\ No newline at end of file
+}
